==> qtjambi-texttospeech-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiTextToSpeech/QVoice_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtTextToSpeech/qvoice.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiTextToSpeech/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QVoice(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVoice")
    QVoice *_ptr = reinterpret_cast<QVoice *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QVoice()
void __qt_construct_QVoice(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QVoice()")
    Q_UNUSED(__java_arguments)
    QVoice *__qt_this = new(__qtjambi_ptr) QVoice();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QVoice::QVoice()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_initialize_1native__Lio_qt_texttospeech_QVoice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::QVoice()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVoice, sizeof(QVoice), typeid(QVoice), false, &deleter_QVoice, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QVoice(QVoice)
void __qt_construct_QVoice_cref_QVoice(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QVoice(QVoice)")
    jobject other0 = __java_arguments[0].l;
    const QVoice& __qt_other0 = qtjambi_cast<const QVoice& >(__jni_env, other0);
    QVoice *__qt_this = new(__qtjambi_ptr) QVoice(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QVoice::QVoice(QVoice)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_initialize_1native__Lio_qt_texttospeech_QVoice_2Lio_qt_texttospeech_QVoice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::QVoice(QVoice)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVoice_cref_QVoice, sizeof(QVoice), typeid(QVoice), false, &deleter_QVoice, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QVoice
void __qt_destruct_QVoice(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVoice")
    reinterpret_cast<QVoice*>(ptr)->~QVoice();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVoice::age()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_age_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::age()const", __qt_this)
        QVoice::Age __qt_return_value = __qt_this->age();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::gender()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_gender_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::gender()const", __qt_this)
        QVoice::Gender __qt_return_value = __qt_this->gender();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::operator=(QVoice)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_assign_1native_1cref_1QVoice__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator=(QVoice)", __qt_this)
        const QVoice& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QVoice>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::operator==(QVoice)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_equals_1native_1cref_1QVoice__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator==(QVoice)", __qt_this)
        const QVoice& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QVoice>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::ageName(QVoice::Age)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_ageName_1native_1QVoice_1Age__I)
(JNIEnv *__jni_env,
 jclass,
 jint age0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::ageName(QVoice::Age)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QVoice::Age __qt_age0 = qtjambi_cast<QVoice::Age>(__jni_env, age0);
        QString __qt_return_value = QVoice::ageName(QVoice::Age(__qt_age0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::genderName(QVoice::Gender)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_genderName_1native_1QVoice_1Gender__I)
(JNIEnv *__jni_env,
 jclass,
 jint gender0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::genderName(QVoice::Gender)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QVoice::Gender __qt_gender0 = qtjambi_cast<QVoice::Gender>(__jni_env, gender0);
        QString __qt_return_value = QVoice::genderName(QVoice::Gender(__qt_gender0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QVoice(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QVoice>("QVoice", "io/qt/texttospeech/QVoice");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QVoice, {
        ConstructorInfo(&__qt_construct_QVoice, nullptr)
       ,ConstructorInfo(&__qt_construct_QVoice_cref_QVoice, "Lio/qt/texttospeech/QVoice;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVoice);
    registerMetaType<QVoice>("QVoice");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVoice::Age>("QVoice::Age", "io/qt/texttospeech/QVoice$Age");
    registerEnumTypeInfo<QVoice::Gender>("QVoice::Gender", "io/qt/texttospeech/QVoice$Gender");
// END: enums and flags
}

==> qtjambi-texttospeech-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiTextToSpeech/QVoice_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtTextToSpeech/qvoice.h>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qlocale.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiTextToSpeech/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QVoice(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVoice")
    QVoice *_ptr = reinterpret_cast<QVoice *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QVoice()
void __qt_construct_QVoice_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QVoice()")
    Q_UNUSED(__java_arguments)
    QVoice *__qt_this = new(__qtjambi_ptr) QVoice();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QVoice(QVoice)
void __qt_construct_QVoice_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QVoice(QVoice)")
    jobject other0 = __java_arguments[0].l;
    const QVoice& __qt_other0 = qtjambi_cast<const QVoice& >(__jni_env, other0);
    QVoice *__qt_this = new(__qtjambi_ptr) QVoice(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QVoice
void __qt_destruct_QVoice(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVoice")
    reinterpret_cast<QVoice*>(ptr)->~QVoice();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVoice::QVoice()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_initialize_1native__Lio_qt_texttospeech_QVoice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::QVoice()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVoice_0, sizeof(QVoice), typeid(QVoice), false, &deleter_QVoice, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::QVoice(QVoice)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_initialize_1native__Lio_qt_texttospeech_QVoice_2Lio_qt_texttospeech_QVoice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::QVoice(QVoice)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVoice_1, sizeof(QVoice), typeid(QVoice), false, &deleter_QVoice, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::age()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_age_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::age()const", __qt_this)
        QVoice::Age __qt_return_value = __qt_this->age();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::gender()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_gender_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::gender()const", __qt_this)
        QVoice::Gender __qt_return_value = __qt_this->gender();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::locale()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_locale_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::locale()const", __qt_this)
        QLocale __qt_return_value = __qt_this->locale();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::operator<<(QDataStream&,QVoice)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_writeTo_1native_1ref_1QDataStream__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID str0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator<<(QDataStream&,QVoice)", __qt_this)
        QDataStream& __qt_str0 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, str0);
        __qt_str0 << (*__qt_this);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::operator=(QVoice)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_assign_1native_1cref_1QVoice__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator=(QVoice)", __qt_this)
        const QVoice& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QVoice>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::operator==(QVoice,QVoice)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_operator_1equal_1native_1cref_1QVoice__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator==(QVoice,QVoice)", __qt_this)
        const QVoice& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QVoice>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::operator>>(QDataStream&,QVoice&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_readFrom_1native_1ref_1QDataStream__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID str0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::operator>>(QDataStream&,QVoice&)", __qt_this)
        QDataStream& __qt_str0 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, str0);
        __qt_str0 >> (*__qt_this);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::swap(QVoice&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_swap_1native_1ref_1QVoice__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVoice::swap(QVoice&)", __qt_this)
        QVoice& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QVoice>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVoice::ageName(QVoice::Age)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_ageName_1native_1QVoice_1Age__I)
(JNIEnv *__jni_env,
 jclass,
 jint age0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::ageName(QVoice::Age)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QVoice::Age __qt_age0 = qtjambi_cast<QVoice::Age>(__jni_env, age0);
        QString __qt_return_value = QVoice::ageName(QVoice::Age(__qt_age0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QVoice::genderName(QVoice::Gender)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_genderName_1native_1QVoice_1Gender__I)
(JNIEnv *__jni_env,
 jclass,
 jint gender0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVoice::genderName(QVoice::Gender)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QVoice::Gender __qt_gender0 = qtjambi_cast<QVoice::Gender>(__jni_env, gender0);
        QString __qt_return_value = QVoice::genderName(QVoice::Gender(__qt_gender0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_texttospeech_QVoice_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QVoice *__qt_this = QtJambiAPI::objectFromNativeId<QVoice>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QVoice(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QVoice>("QVoice", "io/qt/texttospeech/QVoice");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QVoice, {
        ConstructorInfo(&__qt_construct_QVoice_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QVoice_1, "Lio/qt/texttospeech/QVoice;")
    });
// END: function table

    registerMetaObject(typeId, QVoice::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVoice);
    registerMetaType<QVoice>("QVoice");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVoice::Age>("QVoice::Age", "io/qt/texttospeech/QVoice$Age");
    registerEnumTypeInfo<QVoice::Gender>("QVoice::Gender", "io/qt/texttospeech/QVoice$Gender");
// END: enums and flags
}
